              ###--- Diversity of Triassic thylacocephalans ---###

# packages -----
library("tidyverse")
library("ggpubr")
library("deeptime")

# data -----
tab<-read.csv("Data/triassic-thylacocephalans.csv", header = T, sep = ",", quote = "'", stringsAsFactors = T)
summary(tab)

# Analyses -----
  ## Sort levels
tab$Epoch<-fct_relevel(tab$epoch, c("Early Triassic", "Middle Triassic", "Late Triassic"))
tab$Stage<-fct_relevel(tab$stage, c("Olenekian", "Anisian", "Ladinian", "Carnian", "Norian"))


  ## Calculate taxonomic richness per epochs
diversity_by_epo<-tab %>%
  group_by(Epoch, species)%>% #number of occurrence of species by period
  summarise(n = n()) %>%
  group_by(Epoch)%>% #number of species by epochs
  summarise(nspecies = n())

  ## Calculate taxonomic richness per stage
diversity_by_stage<-tab %>%
  group_by(Stage, species)%>% #number of occurrence of species by period
  summarise(n = n()) %>%
  group_by(Stage)%>% #number of species by stage
  summarise(nspecies = n())

# Plots -----
  ## Taxonomic richness by epoch
div_epo<-div_stage<-ggplot(diversity_by_epo) +
  geom_col(aes(x = Epoch, y = nspecies, fill=Epoch))+
  scale_x_discrete(limits = unique(levels(diversity_by_epo$Epoch)), labels = NULL, expand = expansion(add = .5))+
  geom_text(aes(x = Epoch, y = nspecies, label=nspecies), vjust=1.5, color="white", size=3.25, fontface='bold')+
  scale_y_continuous(limits = c(0,12), expand = c(0,0))+
  scale_fill_manual(values=epochs$color[c(15:13)])+
  xlab("")+
  ylab("Taxonomic richness (species)")+
  coord_geo(dat="epochs", expand = TRUE, skip = NULL, abbrv = F, size = 'auto', lwd=0.5, fittext_args=list(fontface='bold'))+
  theme_classic() +
  theme(legend.position="none", axis.ticks.length.x = unit(0, "lines"), axis.title.y = element_text(face="bold"), 
        axis.text.y = element_text(size = 9))
div_epo

  ## Taxonomic richness by stage
div_stage<-ggplot(diversity_by_stage) +
  geom_col(aes(x = Stage, y = nspecies, fill=Stage))+
  scale_x_discrete(limits = unique(levels(diversity_by_stage$Stage)), labels = NULL, expand = expansion(add = .5))+
  geom_text(aes(x = Stage, y = nspecies, label=nspecies), vjust=1.5, color="white", size=3.25, fontface='bold')+
  scale_y_continuous(limits = c(0,12), expand = c(0,0))+
  scale_fill_manual(values=stages$color[c(53:49)])+
  xlab("")+
  ylab("Taxonomic richness (species)")+
  coord_geo(dat="stages", expand = TRUE, skip = NULL, abbrv = F, size = 'auto', lwd=0.5, fittext_args=list(fontface='bold'))+
  theme_classic() +
  theme(legend.position="none", axis.ticks.length.x = unit(0, "lines"), axis.title.y = element_text(face="bold"), 
        axis.text.y = element_text(size = 9))
div_stage

  ## Combine plots
figure<-ggarrange(div_epo, div_stage,labels = c("A", "B"), font.label=list(size = 16, face = "bold", color ="Black"), ncol = 1, nrow = 2)
figure
ggexport(figure, filename = "Figures/figure_20.tiff", res=600, width = 4000, height=6000)